<?php
/*
Plugin Name: WordPress MU Aggregator
Plugin URI: http://strangework.com/wordpress-plugins/
Description: Retrieves a list of most recent posts from all blogs in a WordPress MU installation.  Enter <code>&lt;php wp_mu_aggregator(10); ?></code> where you want the posts to display in your theme.
Version: 0.5
Author: Brad Williams
Author URI: http://strangework.com/

Based on WordPress MU Recent Posts
Original Author: Ron Rennick
Original Author URI: http://atypicalhomeschool.net/

Features:
Supports permalinks, non-friendly links (querystrings), or a mixture of both
Easy to read comments for easy edits and styling
Style-less to allow for easy implementation in any theme.
More features and sidebar widgets coming soon
*/

function wp_mu_aggregator($how_many) {
	global $wpdb;
	$counter = 0;

	// get a list of blogs in order of most recent update
	// will only return blogs that have updated in the last 30 days
	$blogs = $wpdb->get_col("SELECT blog_id FROM $wpdb->blogs WHERE
		last_updated >= DATE_SUB(CURRENT_DATE(), INTERVAL 30 DAY)
		ORDER BY last_updated DESC");

	if ($blogs) {
		foreach ($blogs as $blog) {
			// we need _posts and _options tables for this to work
			$blogOptionsTable = "wp_".$blog."_options";

		    $blogPostsTable = "wp_".$blog."_posts";

			$options = $wpdb->get_results("SELECT option_value FROM
				$blogOptionsTable WHERE option_name IN ('siteurl','blogname')
				ORDER BY option_name DESC");

		    // we fetch the title and link for the latest post
		    // will only return posts from the last 30 days
			$thispost = $wpdb->get_results("SELECT ID, post_title, guid, post_name, post_content
				FROM $blogPostsTable WHERE post_status = 'publish'
				AND post_type = 'post' AND post_date >= DATE_SUB(CURRENT_DATE(), INTERVAL 30 DAY)
				ORDER BY id DESC LIMIT 0,1");

			// if it is found put it to the output
			if($thispost) {

				//create permalink for the blog post
				$permalink=get_blog_permalink($blog, $thispost[0]->ID);

				//if permalink exists use it, if not use ID
				If($permalink) {
					$URI=$permalink;
				}Else{
					$URI=$thispost[0]->guid;
				}

				//display post title
				echo '<a href="'.$URI.'">'.$thispost[0]->post_title.'</a>';

				echo '<br />';

				//display [Posted by website URL]
				echo 'Posted by <a href="'.$options[0]->option_value.'">'.$options[1]->option_value."</a>";

				echo '<br />';

				//display post content
				echo $thispost[0]->post_content.'<br /><br />';

				$counter++;
			}
			// don't go over the limit
			if($counter >= $how_many) {
				break;
			}
		}
	}
}
?>